import { type HTTPHeaders } from '@trpc/client';
import type { AnyRouter, ClientDataTransformerOptions } from '@trpc/server';
export type TRPCClientInit = {
    fetch?: typeof window.fetch;
    url: {
        origin: string;
    };
};
/**
 * Create a tRPC client.
 * @see https://trpc.io/docs/vanilla
 */
export declare function createTRPCClient<Router extends AnyRouter>({ url, transformer, init, headers }?: {
    /**
     * The tRPC api endpoint URL.
     * @default '/trpc'
     */
    url?: `/${string}`;
    /**
     * A function that transforms the data before transferring it.
     * @see https://trpc.io/docs/data-transformers
     */
    transformer?: ClientDataTransformerOptions;
    /**
     * A page store or SvelteKit load event.
     * @see https://kit.svelte.dev/docs/modules#$app-stores
     * @see https://kit.svelte.dev/docs/load
     */
    init?: TRPCClientInit;
    /**
     * Additional headers to send with the request. Can be a function that returns headers.
     * @see https://developer.mozilla.org/en-US/docs/Web/API/Headers
     */
    headers?: HTTPHeaders | (() => HTTPHeaders | Promise<HTTPHeaders>);
}): Router["_def"]["record"] extends infer T extends import("@trpc/server").ProcedureRouterRecord ? { [TKey in keyof T]: Router["_def"]["record"][TKey] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"] extends infer T_1 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_1 in keyof T_1]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"] extends infer T_2 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_2 in keyof T_2]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"] extends infer T_3 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_3 in keyof T_3]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"] extends infer T_4 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_4 in keyof T_4]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"] extends infer T_5 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_5 in keyof T_5]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"] extends infer T_6 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_6 in keyof T_6]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"] extends infer T_7 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_7 in keyof T_7]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"] extends infer T_8 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_8 in keyof T_8]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"] extends infer T_9 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_9 in keyof T_9]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] extends AnyRouter ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"] extends infer T_10 extends import("@trpc/server").ProcedureRouterRecord ? { [TKey_10 in keyof T_10]: Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] extends AnyRouter ? any : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] extends infer T_11 ? T_11 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] ? T_11 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_11["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_11>>;
} : T_11 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_11["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_11>>;
} : T_11 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_11["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_11["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_11>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] extends infer T_12 ? T_12 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] ? T_12 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_12["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_12>>;
} : T_12 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_12["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_12>>;
} : T_12 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_12["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_12["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_12>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] extends infer T_13 ? T_13 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] ? T_13 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_13["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_13>>;
} : T_13 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_13["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_13>>;
} : T_13 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_13["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_13["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_13>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] extends infer T_14 ? T_14 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] ? T_14 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_14["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_14>>;
} : T_14 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_14["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_14>>;
} : T_14 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_14["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_14["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_14>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] extends infer T_15 ? T_15 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] ? T_15 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_15["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_15>>;
} : T_15 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_15["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_15>>;
} : T_15 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_15["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_15["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_15>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] extends infer T_16 ? T_16 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] ? T_16 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_16["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_16>>;
} : T_16 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_16["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_16>>;
} : T_16 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_16["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_16["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_16>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] extends infer T_17 ? T_17 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] ? T_17 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_17["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_17>>;
} : T_17 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_17["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_17>>;
} : T_17 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_17["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_17["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_17>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] extends infer T_18 ? T_18 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] ? T_18 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_18["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_18>>;
} : T_18 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_18["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_18>>;
} : T_18 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_18["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_18["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_18>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] extends infer T_19 ? T_19 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] ? T_19 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_19["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_19>>;
} : T_19 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_19["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_19>>;
} : T_19 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_19["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_19["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_19>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]["_def"]["record"][TKey_1]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey]["_def"]["record"][TKey_1] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey]["_def"]["record"][TKey_1] extends infer T_20 ? T_20 extends Router["_def"]["record"][TKey]["_def"]["record"][TKey_1] ? T_20 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_20["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_20>>;
} : T_20 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_20["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_20>>;
} : T_20 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_20["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_20["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_20>, import("@trpc/client").TRPCClientError<Router["_def"]["record"][TKey]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : Router["_def"]["record"][TKey] extends import("@trpc/server").AnyProcedure ? Router["_def"]["record"][TKey] extends infer T_21 ? T_21 extends Router["_def"]["record"][TKey] ? T_21 extends import("@trpc/server").AnyQueryProcedure ? {
    query: (...args: import("@trpc/server").ProcedureArgs<T_21["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_21>>;
} : T_21 extends import("@trpc/server").AnyMutationProcedure ? {
    mutate: (...args: import("@trpc/server").ProcedureArgs<T_21["_def"]>) => Promise<import("@trpc/server/shared").inferTransformedProcedureOutput<T_21>>;
} : T_21 extends import("@trpc/server").AnySubscriptionProcedure ? {
    subscribe: (input: import("@trpc/server").ProcedureArgs<T_21["_def"]>[0], opts: import("@trpc/server").ProcedureArgs<T_21["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<import("@trpc/server/shared").inferTransformedSubscriptionOutput<T_21>, import("@trpc/client").TRPCClientError<Router>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never;
